# Changelog

## [0.4.1](https://github.com/r0f1/critical_es_value/compare/v0.4.0...v0.4.1) (2025-10-18)


### Documentation

* Documentation improved ([#13](https://github.com/r0f1/critical_es_value/issues/13)) ([83ec952](https://github.com/r0f1/critical_es_value/commit/83ec9520258b8761a9c584e79a3fd25f436423ca))

## [0.4.0](https://github.com/r0f1/critical_es_value/compare/v0.3.1...v0.4.0) (2025-10-18)


### Features

* Various improvements ([#11](https://github.com/r0f1/critical_es_value/issues/11)) ([a2401b3](https://github.com/r0f1/critical_es_value/commit/a2401b311448d3d3e20b2b89d514162f34194860))

## [0.3.1](https://github.com/r0f1/critical_es_value/compare/v0.3.0...v0.3.1) (2025-10-14)


### Bug Fixes

* Token in workflow ([b976fb3](https://github.com/r0f1/critical_es_value/commit/b976fb36e15c7281c36025f0698adce9a0afc223))

## [0.3.0](https://github.com/r0f1/critical_es_value/compare/v0.2.1...v0.3.0) (2025-10-14)


### Features

* CEV-0006 Added new API functions ([#9](https://github.com/r0f1/critical_es_value/issues/9)) ([45b018c](https://github.com/r0f1/critical_es_value/commit/45b018cff66e219f7589e662598b34075e44ab45))


### Documentation

* Added pypi metadata ([#7](https://github.com/r0f1/critical_es_value/issues/7)) ([33cae73](https://github.com/r0f1/critical_es_value/commit/33cae739f819c1d29f7505dc470df5e343347890))
* Added Sphinx ([#8](https://github.com/r0f1/critical_es_value/issues/8)) ([dac7dbf](https://github.com/r0f1/critical_es_value/commit/dac7dbf3809b17a2ed7f17d684146aa2d8c4c099))
* CEV-0003 Add pdoc ([#4](https://github.com/r0f1/critical_es_value/issues/4)) ([4b27082](https://github.com/r0f1/critical_es_value/commit/4b27082171281ef1acd9e1856c113d5a5dffc190))

## [0.2.1](https://github.com/r0f1/critical_es_value/compare/v0.2.0...v0.2.1) (2025-10-14)


### Documentation

* CEV-0001 Improve Docs ([#1](https://github.com/r0f1/critical_es_value/issues/1)) ([e49baff](https://github.com/r0f1/critical_es_value/commit/e49baff46b2f38d857ea507db283a10ba326e12d))
